==> keycloak-model-map-hot-rod-19.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/authSession/HotRodRootAuthenticationSessionEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authSession;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodRootAuthenticationSessionEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity, org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.sessions.RootAuthenticationSessionModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.sessions.RootAuthenticationSessionModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity, org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity.HotRodRootAuthenticationSessionEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-21.1.2-sources.jar: org/keycloak/models/map/storage/hotRod/authSession/HotRodRootAuthenticationSessionEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authSession;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodRootAuthenticationSessionEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity, org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.sessions.RootAuthenticationSessionModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.sessions.RootAuthenticationSessionModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity, org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authSession.HotRodRootAuthenticationSessionEntity.HotRodRootAuthenticationSessionEntitySchema.INSTANCE;
    }
}
